@@ -27,6 +27,7 @@ class StateMachine():
         self._context = context
         self._state_creator_dict = state_creator_dict
         self._transition_dict = transition_dict
+        self._verbose = False
 
     @property
     def context(self):
@@ -43,6 +44,15 @@ class StateMachine():
         """現在の状態"""
         return self._state
 
+    @property
+    def verbose(self):
+        """標準出力にデバッグ情報を出力するなら真"""
+        return self._verbose
+
+    @verbose.setter
+    def verbose(self, val):
+        self._verbose = val
+
     def arrive(self, next_state_name):
         """指定の状態に遷移します
         on_entryコールバック関数を呼び出します。
@@ -53,6 +63,9 @@ class StateMachine():
             次の状態の名前
         """
 
+        if self.verbose:
+            print(f"[state_machine] Arrive to {next_state_name}")
+
         if next_state_name in self._state_creator_dict:
             # 次のステートへ引継ぎ
             self._state = self._state_creator_dict[next_state_name]()
@@ -62,6 +75,8 @@ class StateMachine():
             # このステートをただちに通り過ぎたいなら
             line = self._state.pass_on(self._context)
             if line:
+                if self.verbose:
+                    print(f"[state_machine] Arrive pass_on line={line}")
                 self.leave(line)
 
         else:
@@ -84,6 +99,9 @@ class StateMachine():
             次の状態の名前、遷移に使ったキー
         """
 
+        if self.verbose:
+            print(f"[state_machine] Leave line={line}")
+
         edge_name = self._state.leave(self._context, line)
 
         # さっき去ったステートの名前と、今辿っているエッジの名前
@@ -91,6 +109,10 @@ class StateMachine():
 
         if key in self._transition_dict:
             next_state_name = self._transition_dict[key]
+
+            if self.verbose:
+                print(f"[state_machine] Leave {key}{next_state_name}")
+
         else:
             # Error
             raise ValueError(f"Leave-key [{key}] is not found")
